// Functions for communicating with the background page.

import { PartialStateUpdate } from '../state';
import {
    Actions,
    DownloadTransactionReply,
    DownloadTransactionsMessage,
    EnsureStateMessage,
    EnsureStateReply,
    GetAccountsMessage,
    GetAccountsReply
} from '../background/messages';

export async function getAccounts(): Promise<GetAccountsReply> {
    const message: GetAccountsMessage = { action: Actions.GetAccounts };
    return await browser.runtime.sendMessage(message);
}

export async function ensureState(
    clientState: PartialStateUpdate
): Promise<EnsureStateReply> {
    const message: EnsureStateMessage = { action: Actions.EnsureState, clientState };
    return await browser.runtime.sendMessage(message);
}

export async function downloadTransactions(
    accounts: string[],
    dateFrom: Date,
    dateTo: Date
): Promise<DownloadTransactionReply> {
    const message: DownloadTransactionsMessage = {
        accounts,
        dateFrom,
        dateTo,
        action: Actions.DownloadTransactions
    };
    return await browser.runtime.sendMessage(message);
}
