import * as React from 'jsx-dom'; // necessary for react to work
import { Event, ClientEvents } from '../events';
import * as background from '../background';
import { ExportDiv } from './components';

const logDownload = (accountNumbers: string[], dateFrom: Date, dateTo: Date) =>
    console.info(
	`Downloading transactions from ${dateFrom} to ${dateTo} ` +
	    `for: ${accountNumbers.join(', ')}`
    );

window.addEventListener('DOMContentLoaded', async () => {
    ClientEvents.on(Event.StatePopulated, async () => {
        const response = await background.getAccounts();

        const downloadHandler = async (
	    accountNumbers: string[], dateFrom: Date, dateTo: Date
	) => {
            logDownload(accountNumbers, dateFrom, dateTo);
	    const reply = await background.downloadTransactions(
		accountNumbers, dateFrom, dateTo
	    );

	    if (reply.error == null) {
		console.log(reply.csv);
	    } else {
		console.error(reply.error);
	    }
        };

        if (response.error == null) {
            const exportDiv = (
                <ExportDiv accounts={response.accounts}
                    fromLabel="From" toLabel="To" onDownload={downloadHandler} />
            );

            const contentDiv = document.querySelector(
                'div[class="table-data content-box fill shadow"]'
            );

            contentDiv?.prepend(exportDiv);
        }
    });
});
